@@ -350,6 +350,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         return new OnAudioFocusChangeListener() {
             private boolean mLossTransient = false;
             private boolean mLossTransientCanDuck = false;
+            private boolean wasPlaying = false;
 
             @Override
             public void onAudioFocusChange(int focusChange) {
@@ -361,13 +362,16 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                         Log.i(TAG, "AUDIOFOCUS_LOSS");
                         // Pause playback
                         changeAudioFocus(false);
-                        pause();
+                        if (wasPlaying)
+                            pause();
                         break;
                     case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT:
                         Log.i(TAG, "AUDIOFOCUS_LOSS_TRANSIENT");
                         // Pause playback
                         mLossTransient = true;
-                        mMediaPlayer.pause();
+                        wasPlaying = isPlaying();
+                        if (wasPlaying)
+                            pause();
                         break;
                     case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK:
                         Log.i(TAG, "AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK");
@@ -383,9 +387,9 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                         if (mLossTransientCanDuck) {
                             mMediaPlayer.setVolume(100);
                             mLossTransientCanDuck = false;
-                        }
-                        if (mLossTransient) {
-                            mMediaPlayer.play();
+                        } else if (mLossTransient) {
+                            if (wasPlaying)
+                                mMediaPlayer.play();
                             mLossTransient = false;
                         }
                         break;
@@ -442,6 +446,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     } : null;
 
     private final BroadcastReceiver mReceiver = new BroadcastReceiver() {
+        private boolean wasPlaying = false;
         @Override
         public void onReceive(Context context, Intent intent) {
             String action = intent.getAction();
@@ -505,11 +510,12 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             else if (mDetectHeadset && !mHasHdmiAudio) {
                 if (action.equalsIgnoreCase(AudioManager.ACTION_AUDIO_BECOMING_NOISY)) {
                     Log.i(TAG, "Headset Removed.");
-                    if (hasCurrentMedia())
+                    wasPlaying = isPlaying();
+                    if (wasPlaying && hasCurrentMedia())
                         pause();
                 } else if (action.equalsIgnoreCase(Intent.ACTION_HEADSET_PLUG) && state != 0) {
                     Log.i(TAG, "Headset Inserted.");
-                    if (hasCurrentMedia())
+                    if (wasPlaying && hasCurrentMedia())
                         play();
                 }
             }
